<script setup lang="ts">
import {defineComponent, PropType} from "vue";
import {PatientStatisticVO, RoomBedVO} from "@/api/ecg/doctor";
import {useCheckTypeStore} from "@/store/modules/checkType";

defineComponent({
  name: 'TitlePanel'
})

const  props = defineProps({
  titleType: Number,
  room: {
    type: Object as PropType<RoomBedVO>,
    required: true
  },
  patientStatistic: {
    type: Object as PropType<PatientStatisticVO>,
    required: true
  }
})

const checkTypeStore = useCheckTypeStore();

</script>

<template>
<div class="mytitle">
    <div>
      <img v-if="titleType !== room.opType"
           src="@/assets/imgs/error.png"
           alt="禁止访问本页面，当前工位不符合要求"
           width="20px"
      />
      {{room.roomName || ''}} {{room.bedNo || ''}} {{room.opType === 1?"领用":""}} {{room.opType === 2?"安装":""}}
      <div>
        <span v-for="(checkType, subIndex) in room.checkTypes" :key="subIndex">
          {{getCheckTypeName(checkType)}} &nbsp;
        </span>
      </div>
    </div>
    <div v-if="titleType === 0">
      已检查{{patientStatistic.finishedNum??0}}
      准备中{{patientStatistic.readyNum??0}}
      过号{{patientStatistic.passedNum??0}}
      排队中{{patientStatistic.queuingNum??0}}
    </div>
    <div v-if="titleType === 1">
      已发放{{patientStatistic.receivedNum??0}}
      准备中{{patientStatistic.readyNum??0}}
      过号{{patientStatistic.passedNum??0}}
      排队中{{patientStatistic.queuingNum??0}}
    </div>
    <div v-if="titleType === 2">
      已装机{{patientStatistic.finishedNum??0}}
      待装机{{patientStatistic.receivedNum??0}}
    </div>
</div>

</template>

<style scoped lang="scss">
.mytitle {
  display: flex;
  justify-content: space-between;
}
</style>
